@@ -1,14 +1,15 @@
 """This module implements the class GeneratesAfforestationSuggestions."""
 
-from ml.ml40.features.functionalities.functionality import Functionality
 from ml.identifier import ID
+from ml.ml40.features.functionalities.functionality import Functionality
 
 
 class GeneratesFellingSuggestions(Functionality):
     """This functionality can generate suggestions regarding how to fell a
     tree.
     """
-    def __init__(self, name="", identifier=""):
+
+    def __init__(self, namespace="fml40", name="", identifier="", parent=None):
         """Initializes the object.
 
         :param name: Object name
@@ -16,8 +17,8 @@ class GeneratesFellingSuggestions(Functionality):
 
         """
         super().__init__(
-            name=name,
-            identifier=identifier)
+            namespace=namespace, name=name, identifier=identifier, parent=parent
+        )
 
     def generateFellingSuggestion(self, tree_Id: ID):
         """Returns a suggestion regarding how to fell a tree.
